==> haskell-commonmark-pandoc-0.2.0.1-89-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-commonmark-pandoc.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 commonmark-pandoc
version:              0.2.0.1
visibility:           public
id:                   commonmark-pandoc-0.2.0.1-2X60foMIQ7k9a8ieOjYteR
key:                  commonmark-pandoc-0.2.0.1-2X60foMIQ7k9a8ieOjYteR
license:              BSD-3-Clause
copyright:            2018-2020 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             https://github.com/jgm/commonmark-hs
synopsis:             Bridge between commonmark and pandoc AST.
description:
    This library provides typeclasses for rendering
    commonmark to Pandoc types.

category:             Text
abi:                  a38e722e468058493a24b000955c1e70
exposed:              True
exposed-modules:      Commonmark.Pandoc
import-dirs:          /usr/lib/ghc-8.10.4/site-local/commonmark-pandoc-0.2.0.1
library-dirs:         /usr/lib/ghc-8.10.4/site-local/commonmark-pandoc-0.2.0.1
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-8.10.4/commonmark-pandoc-0.2.0.1

hs-libraries:         HScommonmark-pandoc-0.2.0.1-2X60foMIQ7k9a8ieOjYteR
depends:
    base-4.14.1.0 commonmark-0.1.1.4-AJzrERlk10zFmGOtYqjRFQ
    commonmark-extensions-0.2.0.4-KVQF0PYf6HFGDIV7BPVQkm
    containers-0.6.2.1 pandoc-types-1.22-FiCgR2zU0PeJAkBj82zVJ0
    text-1.2.4.1

haddock-interfaces:
    /usr/share/doc/haskell-commonmark-pandoc/html/commonmark-pandoc.haddock

haddock-html:         /usr/share/doc/haskell-commonmark-pandoc/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-commonmark-pandoc-0.2.0.1-92-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-commonmark-pandoc.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 commonmark-pandoc
version:              0.2.0.1
visibility:           public
id:                   commonmark-pandoc-0.2.0.1-DZHSluwhBj7HHVPzRIWhI0
key:                  commonmark-pandoc-0.2.0.1-DZHSluwhBj7HHVPzRIWhI0
license:              BSD-3-Clause
copyright:            2018-2020 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             https://github.com/jgm/commonmark-hs
synopsis:             Bridge between commonmark and pandoc AST.
description:
    This library provides typeclasses for rendering
    commonmark to Pandoc types.

category:             Text
abi:                  c8515ab5376289762586120ecfaa03d2
exposed:              True
exposed-modules:      Commonmark.Pandoc
import-dirs:          /usr/lib/ghc-8.10.4/site-local/commonmark-pandoc-0.2.0.1
library-dirs:         /usr/lib/ghc-8.10.4/site-local/commonmark-pandoc-0.2.0.1
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-8.10.4/commonmark-pandoc-0.2.0.1

hs-libraries:         HScommonmark-pandoc-0.2.0.1-DZHSluwhBj7HHVPzRIWhI0
depends:
    base-4.14.1.0 commonmark-0.1.1.4-DA7X3f5SzbUD77Nv1l6ZtO
    commonmark-extensions-0.2.0.4-9rEBbd0qTowFvks42WPTLq
    containers-0.6.2.1 pandoc-types-1.22-IGfE9lI0wR47FBVieJz3I2
    text-1.2.4.1

haddock-interfaces:
    /usr/share/doc/haskell-commonmark-pandoc/html/commonmark-pandoc.haddock

haddock-html:         /usr/share/doc/haskell-commonmark-pandoc/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
